ReadError

Enum ReadError 

pub enum ReadError<FatalDecoderError: Error> {
    FatalError(FatalReadError<FatalDecoderError>),
    EndOfFile,
    CacheIndexOutOfRange {
        index: usize,
        num_caches: usize,
    },
    IOServerChannelFull,
    InvalidBuffer,
}
An error reading the file.

Variants



FatalError(FatalReadError<FatalDecoderError>)

A fatal error occurred. The stream cannot continue.



EndOfFile

The end of the file was reached. The stream must be seeked to an earlier position to continue reading data. Until then, output silence.

If this is returned, then the playhead of the stream did not advance.



CacheIndexOutOfRange

The given cache with index index is out of range of the number of caches assigned to this stream. Please try a different index.

If this is returned, then the playhead of the stream did not advance.

Fields

index: usize
num_caches: usize


IOServerChannelFull

The message channel to the IO server was full.

In theory this should not happen, but if it does, then output silence until the channel has more slots open later.

If this is returned, then the playhead of the stream did not advance.



InvalidBuffer

The given buffer does not match the internal layout of the stream. Check that the number of channels in both are the same.

If this is returned, then the playhead of the stream did not advance.