pub struct ReadData<'a, T: Copy + Clone + Default + Send> { /* private fields */ }Expand description
The sample data returned by a ReadClient.
Implementations
Sourceimpl<'a, T: Copy + Clone + Default + Send> ReadData<'a, T>
impl<'a, T: Copy + Clone + Default + Send> ReadData<'a, T>
Sourcepub fn read_channel(&self, channel: usize) -> &[T]
pub fn read_channel(&self, channel: usize) -> &[T]
Read a single channel of samples.
Use ReadData::num_channels() to get the number of available channels.
The length of this data will be equal to ReadData::num_frames().
Sourcepub fn num_channels(&self) -> usize
pub fn num_channels(&self) -> usize
Return the number of channels in this data.
Sourcepub fn num_frames(&self) -> usize
pub fn num_frames(&self) -> usize
Return the number of samples in a single channel of data.
Sourcepub fn reached_end_of_file(&self) -> bool
pub fn reached_end_of_file(&self) -> bool
This returns (true) if the last frame in this data is the end of the file, (false) otherwise.